/* tslint:disable */
/* eslint-disable */
/**
 * elkar-app
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * The version of the OpenAPI document: 0.1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { mapValues } from '../runtime';
import type { UnpaginatedOutputApplicationUserOutputRecordsInner } from './UnpaginatedOutputApplicationUserOutputRecordsInner';
import {
    UnpaginatedOutputApplicationUserOutputRecordsInnerFromJSON,
    UnpaginatedOutputApplicationUserOutputRecordsInnerFromJSONTyped,
    UnpaginatedOutputApplicationUserOutputRecordsInnerToJSON,
    UnpaginatedOutputApplicationUserOutputRecordsInnerToJSONTyped,
} from './UnpaginatedOutputApplicationUserOutputRecordsInner';

/**
 * 
 * @export
 * @interface UnpaginatedOutputApplicationUserOutput
 */
export interface UnpaginatedOutputApplicationUserOutput {
    /**
     * 
     * @type {Array<UnpaginatedOutputApplicationUserOutputRecordsInner>}
     * @memberof UnpaginatedOutputApplicationUserOutput
     */
    records: Array<UnpaginatedOutputApplicationUserOutputRecordsInner>;
}

/**
 * Check if a given object implements the UnpaginatedOutputApplicationUserOutput interface.
 */
export function instanceOfUnpaginatedOutputApplicationUserOutput(value: object): value is UnpaginatedOutputApplicationUserOutput {
    if (!('records' in value) || value['records'] === undefined) return false;
    return true;
}

export function UnpaginatedOutputApplicationUserOutputFromJSON(json: any): UnpaginatedOutputApplicationUserOutput {
    return UnpaginatedOutputApplicationUserOutputFromJSONTyped(json, false);
}

export function UnpaginatedOutputApplicationUserOutputFromJSONTyped(json: any, ignoreDiscriminator: boolean): UnpaginatedOutputApplicationUserOutput {
    if (json == null) {
        return json;
    }
    return {
        
        'records': ((json['records'] as Array<any>).map(UnpaginatedOutputApplicationUserOutputRecordsInnerFromJSON)),
    };
}

export function UnpaginatedOutputApplicationUserOutputToJSON(json: any): UnpaginatedOutputApplicationUserOutput {
    return UnpaginatedOutputApplicationUserOutputToJSONTyped(json, false);
}

export function UnpaginatedOutputApplicationUserOutputToJSONTyped(value?: UnpaginatedOutputApplicationUserOutput | null, ignoreDiscriminator: boolean = false): any {
    if (value == null) {
        return value;
    }

    return {
        
        'records': ((value['records'] as Array<any>).map(UnpaginatedOutputApplicationUserOutputRecordsInnerToJSON)),
    };
}

