/* tslint:disable */
/* eslint-disable */
/**
 * elkar-app
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * The version of the OpenAPI document: 0.1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { mapValues } from '../runtime';
/**
 * Push notification authentication configuration
 * @export
 * @interface PushNotificationAuth
 */
export interface PushNotificationAuth {
    /**
     * 
     * @type {string}
     * @memberof PushNotificationAuth
     */
    credentials?: string | null;
    /**
     * 
     * @type {Array<string>}
     * @memberof PushNotificationAuth
     */
    schemes: Array<string>;
}

/**
 * Check if a given object implements the PushNotificationAuth interface.
 */
export function instanceOfPushNotificationAuth(value: object): value is PushNotificationAuth {
    if (!('schemes' in value) || value['schemes'] === undefined) return false;
    return true;
}

export function PushNotificationAuthFromJSON(json: any): PushNotificationAuth {
    return PushNotificationAuthFromJSONTyped(json, false);
}

export function PushNotificationAuthFromJSONTyped(json: any, ignoreDiscriminator: boolean): PushNotificationAuth {
    if (json == null) {
        return json;
    }
    return {
        
        'credentials': json['credentials'] == null ? undefined : json['credentials'],
        'schemes': json['schemes'],
    };
}

export function PushNotificationAuthToJSON(json: any): PushNotificationAuth {
    return PushNotificationAuthToJSONTyped(json, false);
}

export function PushNotificationAuthToJSONTyped(value?: PushNotificationAuth | null, ignoreDiscriminator: boolean = false): any {
    if (value == null) {
        return value;
    }

    return {
        
        'credentials': value['credentials'],
        'schemes': value['schemes'],
    };
}

