/* tslint:disable */
/* eslint-disable */
/**
 * elkar-app
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * The version of the OpenAPI document: 0.1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { mapValues } from '../runtime';
/**
 * 
 * @export
 * @interface PaginationInformation
 */
export interface PaginationInformation {
    /**
     * 
     * @type {boolean}
     * @memberof PaginationInformation
     */
    hasMore: boolean;
    /**
     * 
     * @type {number}
     * @memberof PaginationInformation
     */
    page: number;
    /**
     * 
     * @type {number}
     * @memberof PaginationInformation
     */
    total: number;
    /**
     * 
     * @type {number}
     * @memberof PaginationInformation
     */
    totalPages: number;
}

/**
 * Check if a given object implements the PaginationInformation interface.
 */
export function instanceOfPaginationInformation(value: object): value is PaginationInformation {
    if (!('hasMore' in value) || value['hasMore'] === undefined) return false;
    if (!('page' in value) || value['page'] === undefined) return false;
    if (!('total' in value) || value['total'] === undefined) return false;
    if (!('totalPages' in value) || value['totalPages'] === undefined) return false;
    return true;
}

export function PaginationInformationFromJSON(json: any): PaginationInformation {
    return PaginationInformationFromJSONTyped(json, false);
}

export function PaginationInformationFromJSONTyped(json: any, ignoreDiscriminator: boolean): PaginationInformation {
    if (json == null) {
        return json;
    }
    return {
        
        'hasMore': json['has_more'],
        'page': json['page'],
        'total': json['total'],
        'totalPages': json['total_pages'],
    };
}

export function PaginationInformationToJSON(json: any): PaginationInformation {
    return PaginationInformationToJSONTyped(json, false);
}

export function PaginationInformationToJSONTyped(value?: PaginationInformation | null, ignoreDiscriminator: boolean = false): any {
    if (value == null) {
        return value;
    }

    return {
        
        'has_more': value['hasMore'],
        'page': value['page'],
        'total': value['total'],
        'total_pages': value['totalPages'],
    };
}

