/* tslint:disable */
/* eslint-disable */
/**
 * elkar-app
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * The version of the OpenAPI document: 0.1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { mapValues } from '../runtime';
/**
 * 
 * @export
 * @interface PartTypeOneOf2
 */
export interface PartTypeOneOf2 {
    /**
     * 
     * @type {{ [key: string]: any; }}
     * @memberof PartTypeOneOf2
     */
    data: { [key: string]: any; };
    /**
     * 
     * @type {string}
     * @memberof PartTypeOneOf2
     */
    type: PartTypeOneOf2TypeEnum;
}


/**
 * @export
 */
export const PartTypeOneOf2TypeEnum = {
    Data: 'data'
} as const;
export type PartTypeOneOf2TypeEnum = typeof PartTypeOneOf2TypeEnum[keyof typeof PartTypeOneOf2TypeEnum];


/**
 * Check if a given object implements the PartTypeOneOf2 interface.
 */
export function instanceOfPartTypeOneOf2(value: object): value is PartTypeOneOf2 {
    if (!('data' in value) || value['data'] === undefined) return false;
    if (!('type' in value) || value['type'] === undefined) return false;
    return true;
}

export function PartTypeOneOf2FromJSON(json: any): PartTypeOneOf2 {
    return PartTypeOneOf2FromJSONTyped(json, false);
}

export function PartTypeOneOf2FromJSONTyped(json: any, ignoreDiscriminator: boolean): PartTypeOneOf2 {
    if (json == null) {
        return json;
    }
    return {
        
        'data': json['data'],
        'type': json['type'],
    };
}

export function PartTypeOneOf2ToJSON(json: any): PartTypeOneOf2 {
    return PartTypeOneOf2ToJSONTyped(json, false);
}

export function PartTypeOneOf2ToJSONTyped(value?: PartTypeOneOf2 | null, ignoreDiscriminator: boolean = false): any {
    if (value == null) {
        return value;
    }

    return {
        
        'data': value['data'],
        'type': value['type'],
    };
}

