/* tslint:disable */
/* eslint-disable */
/**
 * elkar-app
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * The version of the OpenAPI document: 0.1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { mapValues } from '../runtime';
import type { PaginatedOutputTaskResponseRecordsInner } from './PaginatedOutputTaskResponseRecordsInner';
import {
    PaginatedOutputTaskResponseRecordsInnerFromJSON,
    PaginatedOutputTaskResponseRecordsInnerFromJSONTyped,
    PaginatedOutputTaskResponseRecordsInnerToJSON,
    PaginatedOutputTaskResponseRecordsInnerToJSONTyped,
} from './PaginatedOutputTaskResponseRecordsInner';
import type { PaginationInformation } from './PaginationInformation';
import {
    PaginationInformationFromJSON,
    PaginationInformationFromJSONTyped,
    PaginationInformationToJSON,
    PaginationInformationToJSONTyped,
} from './PaginationInformation';

/**
 * 
 * @export
 * @interface PaginatedOutputTaskResponse
 */
export interface PaginatedOutputTaskResponse {
    /**
     * 
     * @type {PaginationInformation}
     * @memberof PaginatedOutputTaskResponse
     */
    pagination: PaginationInformation;
    /**
     * 
     * @type {Array<PaginatedOutputTaskResponseRecordsInner>}
     * @memberof PaginatedOutputTaskResponse
     */
    records: Array<PaginatedOutputTaskResponseRecordsInner>;
}

/**
 * Check if a given object implements the PaginatedOutputTaskResponse interface.
 */
export function instanceOfPaginatedOutputTaskResponse(value: object): value is PaginatedOutputTaskResponse {
    if (!('pagination' in value) || value['pagination'] === undefined) return false;
    if (!('records' in value) || value['records'] === undefined) return false;
    return true;
}

export function PaginatedOutputTaskResponseFromJSON(json: any): PaginatedOutputTaskResponse {
    return PaginatedOutputTaskResponseFromJSONTyped(json, false);
}

export function PaginatedOutputTaskResponseFromJSONTyped(json: any, ignoreDiscriminator: boolean): PaginatedOutputTaskResponse {
    if (json == null) {
        return json;
    }
    return {
        
        'pagination': PaginationInformationFromJSON(json['pagination']),
        'records': ((json['records'] as Array<any>).map(PaginatedOutputTaskResponseRecordsInnerFromJSON)),
    };
}

export function PaginatedOutputTaskResponseToJSON(json: any): PaginatedOutputTaskResponse {
    return PaginatedOutputTaskResponseToJSONTyped(json, false);
}

export function PaginatedOutputTaskResponseToJSONTyped(value?: PaginatedOutputTaskResponse | null, ignoreDiscriminator: boolean = false): any {
    if (value == null) {
        return value;
    }

    return {
        
        'pagination': PaginationInformationToJSON(value['pagination']),
        'records': ((value['records'] as Array<any>).map(PaginatedOutputTaskResponseRecordsInnerToJSON)),
    };
}

