/* tslint:disable */
/* eslint-disable */
/**
 * elkar-app
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * The version of the OpenAPI document: 0.1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { mapValues } from '../runtime';
/**
 * 
 * @export
 * @interface CreateTenantInput
 */
export interface CreateTenantInput {
    /**
     * 
     * @type {string}
     * @memberof CreateTenantInput
     */
    name: string;
}

/**
 * Check if a given object implements the CreateTenantInput interface.
 */
export function instanceOfCreateTenantInput(value: object): value is CreateTenantInput {
    if (!('name' in value) || value['name'] === undefined) return false;
    return true;
}

export function CreateTenantInputFromJSON(json: any): CreateTenantInput {
    return CreateTenantInputFromJSONTyped(json, false);
}

export function CreateTenantInputFromJSONTyped(json: any, ignoreDiscriminator: boolean): CreateTenantInput {
    if (json == null) {
        return json;
    }
    return {
        
        'name': json['name'],
    };
}

export function CreateTenantInputToJSON(json: any): CreateTenantInput {
    return CreateTenantInputToJSONTyped(json, false);
}

export function CreateTenantInputToJSONTyped(value?: CreateTenantInput | null, ignoreDiscriminator: boolean = false): any {
    if (value == null) {
        return value;
    }

    return {
        
        'name': value['name'],
    };
}

