/* tslint:disable */
/* eslint-disable */
/**
 * elkar-app
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * The version of the OpenAPI document: 0.1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

import { mapValues } from '../runtime';
/**
 * 
 * @export
 * @interface InviteUserInput
 */
export interface InviteUserInput {
    /**
     * 
     * @type {string}
     * @memberof InviteUserInput
     */
    email: string;
}

/**
 * Check if a given object implements the InviteUserInput interface.
 */
export function instanceOfInviteUserInput(value: object): value is InviteUserInput {
    if (!('email' in value) || value['email'] === undefined) return false;
    return true;
}

export function InviteUserInputFromJSON(json: any): InviteUserInput {
    return InviteUserInputFromJSONTyped(json, false);
}

export function InviteUserInputFromJSONTyped(json: any, ignoreDiscriminator: boolean): InviteUserInput {
    if (json == null) {
        return json;
    }
    return {
        
        'email': json['email'],
    };
}

export function InviteUserInputToJSON(json: any): InviteUserInput {
    return InviteUserInputToJSONTyped(json, false);
}

export function InviteUserInputToJSONTyped(value?: InviteUserInput | null, ignoreDiscriminator: boolean = false): any {
    if (value == null) {
        return value;
    }

    return {
        
        'email': value['email'],
    };
}

