/* tslint:disable */
/* eslint-disable */
/**
 * elkar-app
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * The version of the OpenAPI document: 0.1.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */


/**
 * 
 * @export
 */
export const ApplicationUserStatus = {
    Active: 'Active',
    Deleted: 'Deleted',
    Invited: 'Invited'
} as const;
export type ApplicationUserStatus = typeof ApplicationUserStatus[keyof typeof ApplicationUserStatus];


export function instanceOfApplicationUserStatus(value: any): boolean {
    for (const key in ApplicationUserStatus) {
        if (Object.prototype.hasOwnProperty.call(ApplicationUserStatus, key)) {
            if (ApplicationUserStatus[key as keyof typeof ApplicationUserStatus] === value) {
                return true;
            }
        }
    }
    return false;
}

export function ApplicationUserStatusFromJSON(json: any): ApplicationUserStatus {
    return ApplicationUserStatusFromJSONTyped(json, false);
}

export function ApplicationUserStatusFromJSONTyped(json: any, ignoreDiscriminator: boolean): ApplicationUserStatus {
    return json as ApplicationUserStatus;
}

export function ApplicationUserStatusToJSON(value?: ApplicationUserStatus | null): any {
    return value as any;
}

export function ApplicationUserStatusToJSONTyped(value: any, ignoreDiscriminator: boolean): ApplicationUserStatus {
    return value as ApplicationUserStatus;
}

